==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/containerinstance/kotlin/inputs/SecurityContextDefinitionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerinstance.kotlin.inputs

import com.pulumi.azurenative.containerinstance.inputs.SecurityContextDefinitionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * The security context for the container.
 * @property allowPrivilegeEscalation A boolean value indicating whether the init process can elevate its privileges
 * @property capabilities The capabilities to add or drop from a container.
 * @property privileged The flag to determine if the container permissions is elevated to Privileged.
 * @property runAsGroup Sets the User GID for the container.
 * @property runAsUser Sets the User UID for the container.
 * @property seccompProfile a base64 encoded string containing the contents of the JSON in the seccomp profile
 */
public data class SecurityContextDefinitionArgs(
    public val allowPrivilegeEscalation: Output<Boolean>? = null,
    public val capabilities: Output<SecurityContextCapabilitiesDefinitionArgs>? = null,
    public val privileged: Output<Boolean>? = null,
    public val runAsGroup: Output<Int>? = null,
    public val runAsUser: Output<Int>? = null,
    public val seccompProfile: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.containerinstance.inputs.SecurityContextDefinitionArgs> {
    override fun toJava():
        com.pulumi.azurenative.containerinstance.inputs.SecurityContextDefinitionArgs =
        com.pulumi.azurenative.containerinstance.inputs.SecurityContextDefinitionArgs.builder()
            .allowPrivilegeEscalation(allowPrivilegeEscalation?.applyValue({ args0 -> args0 }))
            .capabilities(capabilities?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .privileged(privileged?.applyValue({ args0 -> args0 }))
            .runAsGroup(runAsGroup?.applyValue({ args0 -> args0 }))
            .runAsUser(runAsUser?.applyValue({ args0 -> args0 }))
            .seccompProfile(seccompProfile?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SecurityContextDefinitionArgs].
 */
@PulumiTagMarker
public class SecurityContextDefinitionArgsBuilder internal constructor() {
    private var allowPrivilegeEscalation: Output<Boolean>? = null

    private var capabilities: Output<SecurityContextCapabilitiesDefinitionArgs>? = null

    private var privileged: Output<Boolean>? = null

    private var runAsGroup: Output<Int>? = null

    private var runAsUser: Output<Int>? = null

    private var seccompProfile: Output<String>? = null

    /**
     * @param value A boolean value indicating whether the init process can elevate its privileges
     */
    @JvmName("devnrwsvclpywbmj")
    public suspend fun allowPrivilegeEscalation(`value`: Output<Boolean>) {
        this.allowPrivilegeEscalation = value
    }

    /**
     * @param value The capabilities to add or drop from a container.
     */
    @JvmName("uymikgehpsruhcvb")
    public suspend fun capabilities(`value`: Output<SecurityContextCapabilitiesDefinitionArgs>) {
        this.capabilities = value
    }

    /**
     * @param value The flag to determine if the container permissions is elevated to Privileged.
     */
    @JvmName("qekeclkdbriglvor")
    public suspend fun privileged(`value`: Output<Boolean>) {
        this.privileged = value
    }

    /**
     * @param value Sets the User GID for the container.
     */
    @JvmName("csqvgfjrmqakgpca")
    public suspend fun runAsGroup(`value`: Output<Int>) {
        this.runAsGroup = value
    }

    /**
     * @param value Sets the User UID for the container.
     */
    @JvmName("ixgrhydygapayirc")
    public suspend fun runAsUser(`value`: Output<Int>) {
        this.runAsUser = value
    }

    /**
     * @param value a base64 encoded string containing the contents of the JSON in the seccomp profile
     */
    @JvmName("txvybfusrrykdems")
    public suspend fun seccompProfile(`value`: Output<String>) {
        this.seccompProfile = value
    }

    /**
     * @param value A boolean value indicating whether the init process can elevate its privileges
     */
    @JvmName("plmwaqfphojyeqhu")
    public suspend fun allowPrivilegeEscalation(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.allowPrivilegeEscalation = mapped
    }

    /**
     * @param value The capabilities to add or drop from a container.
     */
    @JvmName("giibodjhagahpilv")
    public suspend fun capabilities(`value`: SecurityContextCapabilitiesDefinitionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.capabilities = mapped
    }

    /**
     * @param argument The capabilities to add or drop from a container.
     */
    @JvmName("wpfohhohxcqpdvcv")
    public suspend
    fun capabilities(argument: suspend SecurityContextCapabilitiesDefinitionArgsBuilder.() -> Unit) {
        val toBeMapped = SecurityContextCapabilitiesDefinitionArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.capabilities = mapped
    }

    /**
     * @param value The flag to determine if the container permissions is elevated to Privileged.
     */
    @JvmName("ndjofvmbkvirawcq")
    public suspend fun privileged(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.privileged = mapped
    }

    /**
     * @param value Sets the User GID for the container.
     */
    @JvmName("gwahqemnulcaktxi")
    public suspend fun runAsGroup(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.runAsGroup = mapped
    }

    /**
     * @param value Sets the User UID for the container.
     */
    @JvmName("vfcqvgjlwpijfxpv")
    public suspend fun runAsUser(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.runAsUser = mapped
    }

    /**
     * @param value a base64 encoded string containing the contents of the JSON in the seccomp profile
     */
    @JvmName("cbliuepjdqxgroky")
    public suspend fun seccompProfile(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.seccompProfile = mapped
    }

    internal fun build(): SecurityContextDefinitionArgs = SecurityContextDefinitionArgs(
        allowPrivilegeEscalation = allowPrivilegeEscalation,
        capabilities = capabilities,
        privileged = privileged,
        runAsGroup = runAsGroup,
        runAsUser = runAsUser,
        seccompProfile = seccompProfile,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/containerinstance/kotlin/inputs/SecurityContextDefinitionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerinstance.kotlin.inputs

import com.pulumi.azurenative.containerinstance.inputs.SecurityContextDefinitionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * The security context for the container.
 * @property allowPrivilegeEscalation A boolean value indicating whether the init process can elevate its privileges
 * @property capabilities The capabilities to add or drop from a container.
 * @property privileged The flag to determine if the container permissions is elevated to Privileged.
 * @property runAsGroup Sets the User GID for the container.
 * @property runAsUser Sets the User UID for the container.
 * @property seccompProfile a base64 encoded string containing the contents of the JSON in the seccomp profile
 */
public data class SecurityContextDefinitionArgs(
    public val allowPrivilegeEscalation: Output<Boolean>? = null,
    public val capabilities: Output<SecurityContextCapabilitiesDefinitionArgs>? = null,
    public val privileged: Output<Boolean>? = null,
    public val runAsGroup: Output<Int>? = null,
    public val runAsUser: Output<Int>? = null,
    public val seccompProfile: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.containerinstance.inputs.SecurityContextDefinitionArgs> {
    override fun toJava():
        com.pulumi.azurenative.containerinstance.inputs.SecurityContextDefinitionArgs =
        com.pulumi.azurenative.containerinstance.inputs.SecurityContextDefinitionArgs.builder()
            .allowPrivilegeEscalation(allowPrivilegeEscalation?.applyValue({ args0 -> args0 }))
            .capabilities(capabilities?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .privileged(privileged?.applyValue({ args0 -> args0 }))
            .runAsGroup(runAsGroup?.applyValue({ args0 -> args0 }))
            .runAsUser(runAsUser?.applyValue({ args0 -> args0 }))
            .seccompProfile(seccompProfile?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SecurityContextDefinitionArgs].
 */
@PulumiTagMarker
public class SecurityContextDefinitionArgsBuilder internal constructor() {
    private var allowPrivilegeEscalation: Output<Boolean>? = null

    private var capabilities: Output<SecurityContextCapabilitiesDefinitionArgs>? = null

    private var privileged: Output<Boolean>? = null

    private var runAsGroup: Output<Int>? = null

    private var runAsUser: Output<Int>? = null

    private var seccompProfile: Output<String>? = null

    /**
     * @param value A boolean value indicating whether the init process can elevate its privileges
     */
    @JvmName("pnewecqesvaagkmd")
    public suspend fun allowPrivilegeEscalation(`value`: Output<Boolean>) {
        this.allowPrivilegeEscalation = value
    }

    /**
     * @param value The capabilities to add or drop from a container.
     */
    @JvmName("xvbvaiufgptxlmcl")
    public suspend fun capabilities(`value`: Output<SecurityContextCapabilitiesDefinitionArgs>) {
        this.capabilities = value
    }

    /**
     * @param value The flag to determine if the container permissions is elevated to Privileged.
     */
    @JvmName("uuhbanuxeducnuaw")
    public suspend fun privileged(`value`: Output<Boolean>) {
        this.privileged = value
    }

    /**
     * @param value Sets the User GID for the container.
     */
    @JvmName("fupfkrnxtathjpgm")
    public suspend fun runAsGroup(`value`: Output<Int>) {
        this.runAsGroup = value
    }

    /**
     * @param value Sets the User UID for the container.
     */
    @JvmName("kowabxhdjtxrshue")
    public suspend fun runAsUser(`value`: Output<Int>) {
        this.runAsUser = value
    }

    /**
     * @param value a base64 encoded string containing the contents of the JSON in the seccomp profile
     */
    @JvmName("kficpwofqbabowun")
    public suspend fun seccompProfile(`value`: Output<String>) {
        this.seccompProfile = value
    }

    /**
     * @param value A boolean value indicating whether the init process can elevate its privileges
     */
    @JvmName("qhplcysmfkoqdrnr")
    public suspend fun allowPrivilegeEscalation(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.allowPrivilegeEscalation = mapped
    }

    /**
     * @param value The capabilities to add or drop from a container.
     */
    @JvmName("incdiohafoewyjjj")
    public suspend fun capabilities(`value`: SecurityContextCapabilitiesDefinitionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.capabilities = mapped
    }

    /**
     * @param argument The capabilities to add or drop from a container.
     */
    @JvmName("cvjhucxfklrvfifi")
    public suspend
    fun capabilities(argument: suspend SecurityContextCapabilitiesDefinitionArgsBuilder.() -> Unit) {
        val toBeMapped = SecurityContextCapabilitiesDefinitionArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.capabilities = mapped
    }

    /**
     * @param value The flag to determine if the container permissions is elevated to Privileged.
     */
    @JvmName("hloqrvhdbmxvyadj")
    public suspend fun privileged(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.privileged = mapped
    }

    /**
     * @param value Sets the User GID for the container.
     */
    @JvmName("ijkkqacluxmlxuyh")
    public suspend fun runAsGroup(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.runAsGroup = mapped
    }

    /**
     * @param value Sets the User UID for the container.
     */
    @JvmName("yjvorntqtsiferje")
    public suspend fun runAsUser(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.runAsUser = mapped
    }

    /**
     * @param value a base64 encoded string containing the contents of the JSON in the seccomp profile
     */
    @JvmName("lpjygowgnqjynobm")
    public suspend fun seccompProfile(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.seccompProfile = mapped
    }

    internal fun build(): SecurityContextDefinitionArgs = SecurityContextDefinitionArgs(
        allowPrivilegeEscalation = allowPrivilegeEscalation,
        capabilities = capabilities,
        privileged = privileged,
        runAsGroup = runAsGroup,
        runAsUser = runAsUser,
        seccompProfile = seccompProfile,
    )
}
